
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '34.6.0',
    'branch_nick': 'release-34',
    'revision_id': '14a3156fbd023eda4fb32c268d739f089a582f4a',
    'revno': 12971
}
